Improve this doc

# Error: $sanitize:badparse
Parsing Error while Sanitizing

    The sanitizer was unable to parse the following block of html: {0}

## Description

This error occurs when the HTML string passed to '$sanitize' can't be parsed by the sanitizer. The error contains part of the html string that can't be parsed.

The parser is more strict than a typical browser parser, so it's possible that some obscure input would produce this error despite the string being recognized as valid HTML by a browser.

If a valid html code results in this error, please file a bug.